@@ -25,12 +25,20 @@
 #include <QString>
 #include <QLineEdit>
 
+#include "analogmeterwidget.h"
+#include "horizontalvolumebarwidget.h"
+#include "volumelinechartwidget.h"
+
 MainWindow::MainWindow(QWidget *parent) :
     QMainWindow(parent),
     ui(new Ui::MainWindow)
 {
     ui->setupUi(this);
 
+    meter = 0;
+    volumeMeterWidget = NULL;
+    changeMeter();
+
     setDbScale();
 
     ui->currentVolume->setNum(0);
@@ -75,18 +83,41 @@ MainWindow::~MainWindow()
     context_stop();
 }
 
+void MainWindow::changeMeter(){
+    if(volumeMeterWidget != NULL){
+        disconnect(volumeMeterWidget, SIGNAL(clicked()), this, SLOT(changeMeter()));
+        delete volumeMeterWidget;
+        meter = ++meter % 3;
+    }
+
+    switch(meter){
+    case 0:
+        volumeMeterWidget = new AnalogMeterWidget(this);
+        break;
+    case 1:
+        volumeMeterWidget = new HorizontalVolumeBarWidget(this);
+        break;
+    case 2:
+        volumeMeterWidget = new VolumeLineChartWidget(this);
+    }
+
+    volumeMeterWidget->setDbUnit(ui->radioButtonDb->isChecked());
+    ui->volumeMeterLayout->addWidget(volumeMeterWidget);
+    connect(volumeMeterWidget, SIGNAL(clicked()), this, SLOT(changeMeter()));
+}
+
 void MainWindow::resetMaxValue(){
     maxVol = 0;
     ui->maximumVolume->setNum(maxVol);
 }
 
 void MainWindow::setLinearScale(){
-    ui->vuMeterWidget->setDbUnit(false);
+    volumeMeterWidget->setDbUnit(false);
     resetMaxValue();
 }
 
 void MainWindow::setDbScale(){
-    ui->vuMeterWidget->setDbUnit(true);
+    volumeMeterWidget->setDbUnit(true);
     resetMaxValue();
 }
 
@@ -125,7 +156,7 @@ void MainWindow::updateValues(float value){
         vol = 0;
     }
 
-    ui->vuMeterWidget->updateValue(vol);
+    volumeMeterWidget->updateValue(vol);
     ui->currentVolume->setNum(vol);
     if(maxVol < vol){
         maxVol = vol;
