@@ -23,6 +23,8 @@
 #include <QMainWindow>
 #include <QStringList>
 
+#include <volumemeterwidget.h>
+
 namespace Ui {
     class MainWindow;
 }
@@ -44,7 +46,9 @@ private:
     Ui::MainWindow *ui;
 
     int maxVol;
+    int meter;
     QStringList *sources;
+    VolumeMeterWidget *volumeMeterWidget;
 
 private slots:
     void resetMaxValue();
@@ -52,6 +56,7 @@ private slots:
     void setDbScale();
     void sourceChanged(int source);
     void updateValues(float value);
+    void changeMeter();
 };
 
 #endif // MAINWINDOW_H
