@@ -20,30 +20,28 @@
 #ifndef VOLUMEMETERWIDGET_H
 #define VOLUMEMETERWIDGET_H
 
-#include <QPainter>
-#include <QPaintEvent>
 #include <QWidget>
 
+#define MAX_DB 110
+#define MAX_LINEAR 200
+
 class VolumeMeterWidget : public QWidget
 {
     Q_OBJECT
 public:
     explicit VolumeMeterWidget(QWidget *parent = 0);
 
-    void draw(QPainter *painter);
-    void updateValue(int value);
-
-    void setDbUnit(bool b);
+    virtual void updateValue(int value);
+    virtual void setDbUnit(bool b);
 
 signals:
+    void clicked();
 
 protected:
-    void paintEvent(QPaintEvent *event);
-
-private:
     int currentValue;
     bool dbUnit;
 
+    void mouseReleaseEvent(QMouseEvent *);
 };
 
 #endif // VOLUMEMETERWIDGET_H
